CHANGES
=======

2.0.0
-----

* Make username and apikey required, pass kwargs
* Add tests
* Add tox-gh-actions
* Let tox manage python versions
* Feature/updates gitignore (#24)
* Remove MAX\_FILE\_SIZE\_MB
* Update README.md

1.1.1
-----

* Unpin requests
* Update python-package.yml
* Update README.md
* Force push fresh autodocs to github pages

1.1.0
-----

* Add update\_document
* Add portray autodocs
* Fix code


1.0.0
-----

* Clean test deps
* Update README.md

0.0.7
-----

* Fix publish package condition
* Add a note on release
* Fix description, remove authors generation


0.0.6
-----

* Add missing parameters to process\_document\_url
* Add boost
* Make it black (#4)
* Clean python versions
* Bump to 0.0.5
* Remove python 3.5 support
* Add responses
* Clean setup
* Add test
* Fix file\_url parameter, add Accept header
* Better message in exceptions